@@ -1,16 +1,14 @@
 # frozen_string_literal: true
 
 module FFaker
-  VERSION = '2.13.0'
-
-  require 'ffaker/utils/array_utils'
-  require 'ffaker/utils/module_utils'
+  require_relative 'ffaker/utils/array_utils'
+  require_relative 'ffaker/utils/module_utils'
 
   extend ModuleUtils
 
   BASE_LIB_PATH = File.expand_path(__dir__)
 
-  LETTERS = [*'a'..'z'].freeze
+  LETTERS = Array('a'..'z').freeze
 
   HEX = %w[0 1 2 3 4 5 6 7 8 9 A B C D E F].freeze
 
@@ -45,6 +43,7 @@ module FFaker
   autoload :AddressGR, 'ffaker/address_gr'
   autoload :AddressID, 'ffaker/address_id'
   autoload :AddressIN, 'ffaker/address_in'
+  autoload :AddressIT, 'ffaker/address_it'
   autoload :AddressJA, 'ffaker/address_ja'
   autoload :AddressKR, 'ffaker/address_kr'
   autoload :AddressMX, 'ffaker/address_mx'
@@ -57,10 +56,11 @@ module FFaker
   autoload :AddressUK, 'ffaker/address_uk'
   autoload :AddressUS, 'ffaker/address_us'
   autoload :Airline, 'ffaker/airline'
-  autoload :Animal, 'ffaker/animals'
-  autoload :AnimalCN, 'ffaker/animals_cn'
+  autoload :Animal, 'ffaker/animal'
+  autoload :AnimalCN, 'ffaker/animal_cn'
+  autoload :AnimalES, 'ffaker/animal_es'
   autoload :AnimalPL, 'ffaker/animal_pl'
-  autoload :AnimalUS, 'ffaker/animals_us'
+  autoload :AnimalUS, 'ffaker/animal_us'
   autoload :Avatar, 'ffaker/avatar'
   autoload :AWS, 'ffaker/aws'
   autoload :BaconIpsum, 'ffaker/bacon_ipsum'
@@ -74,24 +74,31 @@ module FFaker
   autoload :ColorUA, 'ffaker/color_ua'
   autoload :Company, 'ffaker/company'
   autoload :CompanyCN, 'ffaker/company_cn'
+  autoload :CompanyFR, 'ffaker/company_fr'
   autoload :CompanyIT, 'ffaker/company_it'
+  autoload :CompanyJA, 'ffaker/company_ja'
   autoload :CompanySE, 'ffaker/company_se'
   autoload :Conference, 'ffaker/conference'
-  autoload :CoursesFR, 'ffaker/courses'
+  autoload :CoursesFR, 'ffaker/courses_fr'
   autoload :Currency, 'ffaker/currency'
   autoload :DizzleIpsum, 'ffaker/dizzle_ipsum'
   autoload :Education, 'ffaker/education'
   autoload :EducationCN, 'ffaker/education_cn'
   autoload :Filesystem, 'ffaker/filesystem'
   autoload :Food, 'ffaker/food'
+  autoload :FoodPL, 'ffaker/food_pl'
+  autoload :FreedomIpsum, 'ffaker/freedom_ipsum'
+  autoload :Game, 'ffaker/game'
   autoload :Gender, 'ffaker/gender'
   autoload :GenderBR, 'ffaker/gender_br'
   autoload :GenderCN, 'ffaker/gender_cn'
   autoload :GenderID, 'ffaker/gender_id'
+  autoload :GenderIT, 'ffaker/gender_it'
   autoload :GenderJA, 'ffaker/gender_ja'
   autoload :GenderJP, 'ffaker/gender_jp'
   autoload :GenderKR, 'ffaker/gender_kr'
   autoload :GenderPL, 'ffaker/gender_pl'
+  autoload :GenderRU, 'ffaker/gender_ru'
   autoload :Geolocation, 'ffaker/geolocation'
   autoload :Guid, 'ffaker/guid'
   autoload :HealthcareIpsum, 'ffaker/healthcare_ipsum'
@@ -103,9 +110,12 @@ module FFaker
   autoload :IdentificationES, 'ffaker/identification_es'
   autoload :IdentificationESCL, 'ffaker/identification_es_cl'
   autoload :IdentificationESCO, 'ffaker/identification_es_co'
+  autoload :IdentificationIN, 'ffaker/identification_in'
+  autoload :IdentificationIT, 'ffaker/identification_it'
   autoload :IdentificationKr, 'ffaker/identification_kr'
   autoload :IdentificationMX, 'ffaker/identification_mx'
   autoload :IdentificationPL, 'ffaker/identification_pl'
+  autoload :IdentificationTW, 'ffaker/identification_tw'
   autoload :Image, 'ffaker/image'
   autoload :Internet, 'ffaker/internet'
   autoload :InternetSE, 'ffaker/internet_se'
@@ -113,15 +123,18 @@ module FFaker
   autoload :JobBR, 'ffaker/job_br'
   autoload :JobCN, 'ffaker/job_cn'
   autoload :JobFR, 'ffaker/job_fr'
+  autoload :JobIT, 'ffaker/job_it'
   autoload :JobJA, 'ffaker/job_ja'
   autoload :JobKR, 'ffaker/job_kr'
   autoload :JobVN, 'ffaker/job_vn'
   autoload :Locale, 'ffaker/locale'
   autoload :Lorem, 'ffaker/lorem'
   autoload :LoremAR, 'ffaker/lorem_ar'
+  autoload :LoremBR, 'ffaker/lorem_br'
   autoload :LoremCN, 'ffaker/lorem_cn'
   autoload :LoremFR, 'ffaker/lorem_fr'
   autoload :LoremIE, 'ffaker/lorem_ie'
+  autoload :LoremIT, 'ffaker/lorem_it'
   autoload :LoremJA, 'ffaker/lorem_ja'
   autoload :LoremKR, 'ffaker/lorem_kr'
   autoload :LoremPL, 'ffaker/lorem_pl'
@@ -160,6 +173,7 @@ module FFaker
   autoload :NameUA, 'ffaker/name_ua'
   autoload :NameVN, 'ffaker/name_vn'
   autoload :NatoAlphabet, 'ffaker/nato_alphabet'
+  autoload :Number, 'ffaker/number'
   autoload :PhoneNumber, 'ffaker/phone_number'
   autoload :PhoneNumberAU, 'ffaker/phone_number_au'
   autoload :PhoneNumberBR, 'ffaker/phone_number_br'
@@ -170,6 +184,7 @@ module FFaker
   autoload :PhoneNumberFR, 'ffaker/phone_number_fr'
   autoload :PhoneNumberID, 'ffaker/phone_number_id'
   autoload :PhoneNumberIT, 'ffaker/phone_number_it'
+  autoload :PhoneNumberJA, 'ffaker/phone_number_ja'
   autoload :PhoneNumberKR, 'ffaker/phone_number_kr'
   autoload :PhoneNumberMX, 'ffaker/phone_number_mx'
   autoload :PhoneNumberNL, 'ffaker/phone_number_nl'
@@ -186,6 +201,7 @@ module FFaker
   autoload :Sport, 'ffaker/sport'
   autoload :SportPL, 'ffaker/sport_pl'
   autoload :SportUS, 'ffaker/sport_us'
+  autoload :SportRU, 'ffaker/sport_ru'
   autoload :SSN, 'ffaker/ssn'
   autoload :SSNMX, 'ffaker/ssn_mx'
   autoload :SSNSE, 'ffaker/ssn_se'
@@ -195,6 +211,7 @@ module FFaker
   autoload :Unit, 'ffaker/unit'
   autoload :UnitEnglish, 'ffaker/unit_english'
   autoload :UnitMetric, 'ffaker/unit_metric'
+  autoload :VERSION, 'version'
   autoload :Vehicle, 'ffaker/vehicle'
   autoload :Venue, 'ffaker/venue'
   autoload :Youtube, 'ffaker/youtube'
