@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 module FFaker
   module CheesyLingo
@@ -31,11 +31,8 @@ module FFaker
     end
 
     def paragraph(number_of_phrases = 10)
-      p = fetch_sample(CHEESY_PHRASES).capitalize.to_s
-      (number_of_phrases - 1).times do |s|
-        s = " #{fetch_sample(CHEESY_PHRASES)}"
-        p << s
-      end
+      p = +fetch_sample(CHEESY_PHRASES).capitalize
+      (number_of_phrases - 1).times { p << " #{fetch_sample(CHEESY_PHRASES)}" }
       p << '.'
     end
   end
