@@ -1,4 +1,4 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 module FFaker
   # Loosely based on http://html-ipsum.com/
@@ -146,11 +146,11 @@ module FFaker
       element_content = if content
                           content
                         else
-                          block_html = ''
+                          block_html = +''
                           yield(block_html)
                           block_html
                         end
-      "<#{element}>#{element_content}</#{element}>"
+      +"<#{element}>#{element_content}</#{element}>"
     end
 
     def word
