@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestAddressSE < Test::Unit::TestCase
   include DeterministicHelper
 
-  ALPHA = /\A[\p{Alpha}]+/.freeze
+  ALPHA = /\A\p{Alpha}+/.freeze
   DIGIT = /\d{1}/.freeze
 
   assert_methods_are_deterministic(
@@ -30,7 +30,7 @@ class TestAddressSE < Test::Unit::TestCase
     assert_match(ALPHA, address)
     assert_match(DIGIT, address)
     assert_match(/SVERIGE/, address)
-    assert_match(/[\, a-z]/, address)
+    assert_match(/[, a-z]/, address)
   end
 
   def test_se_zip_code_frozen
