@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestBook < Test::Unit::TestCase
   include DeterministicHelper
@@ -19,7 +19,7 @@ class TestBook < Test::Unit::TestCase
   end
 
   def test_genre
-    assert_match(%r{[\w\s'\/]+}, @tester.genre)
+    assert_match(%r{[\w\s'/]+}, @tester.genre)
   end
 
   def test_author
@@ -27,7 +27,7 @@ class TestBook < Test::Unit::TestCase
   end
 
   def test_isbn
-    assert_match(/[\d]+/, @tester.isbn)
+    assert_match(/\d+/, @tester.isbn)
   end
 
   def test_description
@@ -35,12 +35,12 @@ class TestBook < Test::Unit::TestCase
   end
 
   def test_cover
-    assert_match(%r{\Ahttps:\/\/robohash\.org\/.+\.png\?size=300x300\z},
+    assert_match(%r{\Ahttps://robohash\.org/.+\.png\?size=300x300\z},
                  @tester.cover)
   end
 
   def test_orly_cover
-    assert_match(%r{\Ahttps:\/\/orly-appstore\.herokuapp\.com\/generate},
+    assert_match(%r{\Ahttps://orly-appstore\.herokuapp\.com/generate},
                  @tester.orly_cover)
   end
 end
