@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestFakerGender < Test::Unit::TestCase
   include DeterministicHelper
 
-  assert_methods_are_deterministic(FFaker::Gender, :random)
+  assert_methods_are_deterministic(FFaker::Gender, :binary, :random)
 
   def setup
     @tester = FFaker::Gender
