@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestHealthcareRU < Test::Unit::TestCase
   include DeterministicHelper
 
-  SPECIALIZATION_REGEX = /\A[А-Яа-я\ \(\)\-]+\z/.freeze
+  SPECIALIZATION_REGEX = /\A[А-Яа-я\ ()\-]+\z/.freeze
 
   assert_methods_are_deterministic(FFaker::HealthcareRU, :doctor_specialization)
 
