@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestLoremRU < Test::Unit::TestCase
   include DeterministicHelper
 
-  SENTENCE_MATCHER = /\A[а-яА-ЯёЁ\-\s\.\!\?,]+\z/.freeze
+  SENTENCE_MATCHER = /\A[а-яА-ЯёЁ\-\s.!?,]+\z/.freeze
   WORDS_MATCHER    = /\A[А-Яа-яёЁ\-\s]+\z/.freeze
   WORD_MATCHER     = /\A[А-Яа-яёЁ\-]+\z/.freeze
 
