@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
+require 'ostruct'
 
 class TestUnits < Test::Unit::TestCase
   include DeterministicHelper
